@@ -11,6 +11,16 @@ import ROOT
 import re
 import copy
 
+print """\
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+This library is now called root2matplotlib; root2matplot is deprecated
+
+If root2matplotlib is not available on your system, you can install it
+from the rootplot package on the Python Package Index:
+    http://packages.python.org/rootplot/
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+"""
+
 
 ################ Define constants
 
