@@ -27,6 +27,16 @@ try:
 except ImportError:
     use_multiprocessing = False
 
+print """\
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+This tool is now called rootplot; overlayHists is deprecated
+
+If rootplot is not available on your system, you can install it from the
+rootplot package on the Python Package Index:
+    http://packages.python.org/rootplot/
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+"""
+
 ## Unless only displaying the help menu, import PyROOT
 if '-h' not in sys.argv and len(sys.argv) > 1:
     try:
@@ -52,11 +62,12 @@ up by running 'cmsenv'."""
 
 ######## Define styles #######################################################
 
-default_styles=r"""import ROOT # allows access to ROOT colors (e.g. ROOT.kRed)
+default_styles=r"""\
+import ROOT # allows access to ROOT colors (e.g. ROOT.kRed)
 
 #### If you place this file in your home directory as '~/.overlayHists', then
-#### it will be automatically loaded whenever you call overlayHists.  Otherwise,
-#### just include it in the arguments to overlayHist to activate it.
+#### it will be automatically loaded whenever you call overlayHists.
+#### Otherwise, just include it in the arguments to overlayHist to activate it.
 
 ##############################################################################
 ######## Handling of LaTeX Expressions in matplotlib #########################
@@ -108,6 +119,9 @@ replace = [
 ##     ('histZmumu.root', r'$Z\rightarrow\mu\mu$'),
 ##     ]
 
+## If empty, all factors set to 1; otherwise, requires list at least nfiles long
+file_scale_factors = []
+
 ## Any of the following lists left empty will be filled according to the
 ## command-line options.  If filled, they must be at least as long as filenames.
 ## To have an entry default to the command-line options, set the value to None.
@@ -120,12 +134,13 @@ linestyles_root = []      # 1 (solid), 2 (dashed), 3 (dotted), 4 (dashdot), ...
 fillstyles_root = []      # 0 (hollow), 1001 (solid), 2001 (hatched), ...
 markersizes = []          # in points for matplotlib
 plotstyles_mpl = []       # 'bar', 'hist', 'errorbar', 'stack'
-drawcommands = []         # a TH1::Draw option, include 'stack' to make stacked
+drawcommands_root = []    # a TH1::Draw option; include 'stack' to make stacked
+alphas_mpl = []           # transparencies for fills (value from 0 to 1)
 
 ##############################################################################
 ######## Global Style Options ################################################
 
-## Colors can be (r, g, b) tuples from 0 to 1 or 0 to 256, ROOT color constants
+## Colors can be (r, g, b) tuples from 0 to 1 or 0 to 255, ROOT color constants
 ## (ROOT.kBlue or 600), or any matplotlib color specification if matplotlib is
 ## available on your system (allows names like 'blue')
 colors = [
@@ -138,12 +153,16 @@ colors = [
     ( 67,  77,  83), # dark grey
     ]
 
+## Used with matplotlib output when --markers is specified
+## http://matplotlib.sourceforge.net/api/
+##        artist_api.html#matplotlib.lines.Line2D.set_marker
 markers_mpl = [
     'o', 's', '^', 'x', '*', 'D', 'h', '1'
     ]
 
+## Used with root output when --markers is specified
+## http://root.cern.ch/root/html/TAttMarker.html
 markers_root = [
-    ## This default set mirrors the matplotlib markers above
      4, # circle
     25, # square
     26, # triangle
@@ -334,12 +353,13 @@ def process_hist_root(path, name, counter, options):
         else:
             dimension = 1
         title, xlabel, ylabel = get_labels(hist, options)
+        hist.Scale(options.file_scale_factors[i])
         if options.area_normalize:
             ylabel = options.area_normalized_title
-        if type(options.normalize) == type(float()):
+        if type(options.normalize) is float:
             ylabel = options.scale_normalized_title % options.normalize
             hist.Scale(options.normalize)
-        if type(options.normalize) == type(int()):
+        if type(options.normalize) is int:
             filename = files[options.normalize - 1].name
             ylabel = options.file_normalized_title % filename
         hist.SetTitle("%s;%s;%s" % (title, xlabel, ylabel))
@@ -348,9 +368,9 @@ def process_hist_root(path, name, counter, options):
         if options.area_normalize:
             integral = hist.Integral()
             if integral: hist.Scale(1. / integral)
-        if type(options.normalize) == type(float()):
+        if type(options.normalize) is float:
             hist.Scale(options.normalize)
-        if type(options.normalize) == type(int()):
+        if type(options.normalize) is int:
             nbins = hist.GetNbinsX()
             lowbin, highbin = 1, nbins + 1
             normhist = hists[options.normalize - 1]
@@ -361,7 +381,7 @@ def process_hist_root(path, name, counter, options):
             integral = normhist.Integral(lowbin, highbin)
             if integral:
                 hist.Scale(integral / hist.Integral(lowbin, highbin))
-        if 'stack' in options.drawcommands[i]:
+        if 'stack' in options.drawcommands_root[i]:
             stack.Add(hist)
         histmax = max(histmax, hist.GetMaximum(), stack.GetMaximum())
     if options.efficiency:
@@ -373,7 +393,7 @@ def process_hist_root(path, name, counter, options):
     if options.gridy or options.grid:
         pads[0].SetGridy(not pads[0].GetGridy())
     legend = ROOT.TLegend(*parse_legend_root(options))
-    for com in options.drawcommands:
+    for com in options.drawcommands_root:
         if 'stack' in com:
             first_draw = prep_first_draw(stack, histmax, options)
             stack.Draw(options.draw)
@@ -399,12 +419,12 @@ def process_hist_root(path, name, counter, options):
                 hist.AddBinContent(nbins, hist.GetBinContent(nbins + 1))
             if options.underflow:
                 hist.AddBinContent(1, hist.GetBinContent(0))
-            if 'stack' not in options.drawcommands[i]:
+            if 'stack' not in options.drawcommands_root[i]:
                 if first_draw:
                     first_draw = prep_first_draw(hist, histmax, options)
-                    hist.Draw(options.drawcommands[i])
+                    hist.Draw(options.drawcommands_root[i])
                 else:
-                    hist.Draw("same " + options.drawcommands[i])
+                    hist.Draw("same " + options.drawcommands_root[i])
         else:
             hist.Draw(options.draw2D)
         legend.AddEntry(hist, file.name)
@@ -455,8 +475,9 @@ def process_hist_mpl(path, name, counter, options):
         else:
             dimension = 1
         title, xlabel, ylabel = get_labels(roothist, options)
+        roothist.Scale(options.file_scale_factors[i])
         if options.normalize:
-            if type(options.normalize) == type(int()):
+            if type(options.normalize) is int:
                 file_name = files[options.normalize - 1].name
                 ylabel = options.file_normalized_title % file_name
             else:
@@ -482,7 +503,7 @@ def process_hist_mpl(path, name, counter, options):
                     hist.scale(1./sum(hist.y))
             if options.normalize:
                 numerhist = hists[options.normalize - 1]
-                if type(options.normalize) == type(int()):
+                if type(options.normalize) is int:
                     hists[options.normalize - 1]
                     if options.range:
                         lowbin, highbin = parse_range(hist.xedges,
@@ -511,18 +532,20 @@ def process_hist_mpl(path, name, counter, options):
         for i, (file, hist) in enumerate(zip(files, hists)):
             if options.plotstyles_mpl[i] == "errorbar":
                 if options.logy:
-                    plt.yscale('log')
+                    # Logy would fail if hist all zeroes
+                    if np.nonzero(hist.y)[0].tolist():
+                        plt.yscale('log')
                 hist.errorbar(yerr=True, fmt=options.markers_mpl[i],
                               color=options.fillcolors[i],
                               ecolor=options.errorbarcolors_mpl[i])
             if options.plotstyles_mpl[i] == "hist":
                 for j in range(hist.nbins):
                     hist.y[j] = max(hist.y[j], 1e-10)
-                hist.hist(alpha=options.alpha, histtype='stepfilled',
+                hist.hist(alpha=options.alphas_mpl[i], histtype='stepfilled',
                           log=options.logy, edgecolor=options.linecolors[i],
                           facecolor=options.fillcolors[i])
             if options.plotstyles_mpl[i] == "bar":
-                hist.bar(alpha=options.alpha, log=options.logy,
+                hist.bar(alpha=options.alphas_mpl[i], log=options.logy,
                          edgecolor=options.linecolors[i],
                          facecolor=options.fillcolors[i])
             if options.logx:
@@ -539,9 +562,13 @@ def process_hist_mpl(path, name, counter, options):
             plt.ylim(ymin=rounded_min)
         if options.zero and not options.logy:
             plt.ylim(ymin=0.)
+        if options.ymin:
+            plt.ylim(ymin=options.ymin)
+        if options.ymax:
+            plt.ylim(ymax=options.ymax)
         if options.efficiency:
             plt.ylim(ymax=1.)
-        elif histmax != 0:
+        elif histmax != 0 and not options.ymax:
             plt.ylim(ymax=histmax * options.top_padding_factor)
         if options.overflow:
             plt.text(hist.x[-1], plt.ylim()[0], options.overflow_text,
@@ -605,6 +632,8 @@ def parse_color(color, tcolor=False):
     """
     if color is None:
         return None
+    elif color == 'none' or color == 'None':
+        return 'none'
     r, g, b = 0, 0, 0
     try:
         color = ROOT.gROOT.GetColor(color)
@@ -711,6 +740,10 @@ def prep_first_draw(hist, histmax, options):
     hist.SetMaximum(histmax * options.top_padding_factor)
     if options.zero and not ROOT.gPad.GetLogy():
         hist.SetMinimum(0.)
+    if options.ymin:
+        hist.SetMinimum(options.ymin)
+    if options.ymax:
+        hist.SetMaximum(options.ymax)
     if options.ratio:
         hist.GetXaxis().SetBinLabel(1, '') # Don't show numbers below top plot
         hist.GetXaxis().SetTitle('')
@@ -857,7 +890,7 @@ def parse_legend_root(options):
     """Return the corners to use for the legend based on options."""
     legend_height = min(options.legend_entry_height * options.nfiles + 0.02,
                         options.max_legend_height)
-    if type(options.legend) == type(int()):
+    if type(options.legend) is int:
         options.legend = options.legend_codes[options.legend]
     elif options.legend.lower() == 'none':
         options.legend = None
@@ -900,8 +933,8 @@ def add_options_from_configuration(options):
     f.write(default_styles)
     f.close()
     if options.config:
-        os.rename(configdir + '/default_overlay_config.py',
-                  'overlayHists_config.py')
+        shutil.move(configdir + '/default_overlay_config.py',
+                    'overlayHists_config.py')
         print "Wrote overlayHists_config.py to the current directory"
         sys.exit(0)
     import default_overlay_config
@@ -929,7 +962,7 @@ def process_options(options):
     elif options.bar: options.mpl = 'bar'
     elif options.errorbar: options.mpl = 'errorbar'
     elif options.hist: options.mpl = 'hist'
-    if options.mpl and type(options.mpl) != type(str()):
+    if options.mpl and type(options.mpl) is not str:
         options.mpl = 'hist'
     try:
         global matplotlib
@@ -975,6 +1008,8 @@ def process_options(options):
             options.normalize = int(options.normalize)
     if options.efficiency_from:
         options.efficiency = True
+    if not options.file_scale_factors:
+        options.file_scale_factors = [1.0 for i in xrange(nfiles)]
     if not options.markers:
         options.markers_mpl = ['o' for i in xrange(nfiles)]
     if not options.linecolors:
@@ -994,25 +1029,27 @@ def process_options(options):
         options.markercolors = options.colors
     if not options.plotstyles_mpl:
         options.plotstyles_mpl = [options.mpl for i in xrange(nfiles)]
-    if not options.drawcommands:
-        options.drawcommands = [options.draw for i in xrange(nfiles)]
+    if not options.drawcommands_root:
+        options.drawcommands_root = [options.draw for i in xrange(nfiles)]
     if not options.markersizes:
         if options.markers: size = ROOT.gStyle.GetMarkerSize()
         else: size = 0
         options.markersizes = [size for i in xrange(nfiles)]
     if not options.errorbarcolors_mpl:
         options.errorbarcolors_mpl = [None for i in xrange(nfiles)]
+    if not options.alphas_mpl:
+        options.alphas_mpl = [options.alpha for i in xrange(nfiles)]
     if options.efficiency:
-        for i in range(len(options.drawcommands)):
-            if options.drawcommands[i] != 'stack':
-                options.drawcommands[i] += 'e'
+        for i in range(len(options.drawcommands_root)):
+            if options.drawcommands_root[i] != 'stack':
+                options.drawcommands_root[i] += 'e'
         options.draw += 'e'
     if options.data:
         i = options.data - 1
         options.linecolors[i] = options.data_color
         options.fillcolors[i] = options.data_color
         options.plotstyles_mpl[i] = 'errorbar'
-        options.drawcommands[i] = 'e'
+        options.drawcommands_root[i] = 'e'
         options.markers_root[i] = options.data_marker
         options.draw = 'nostack hist'
         if not options.markersizes[i]:
@@ -1021,10 +1058,9 @@ def process_options(options):
             options.fillcolors[(i+1)%2] = options.mc_color
     for opt in ['linecolors', 'fillcolors', 'markercolors',
                 'errorbarcolors_mpl']:
-        if 'colors' in opt:
-            colors = getattr(options, opt)
-            setattr(options, opt, [parse_color(x, not options.mpl)
-                                   for x in colors])
+        colors = getattr(options, opt)
+        setattr(options, opt, [parse_color(x, not options.mpl)
+                               for x in colors])
     return options
 
 def process_local_options(options, name):
@@ -1052,13 +1088,13 @@ def main():
 Documentation: http://packages.python.org/root2matplot/
 
 Function: overlays corresponding histograms from several files, dumping the
-  images into a directory structure that mirrors that of the ROOT file and,
-  if output format is pdf, also merging all images into a single file.
-  Most style options can be controlled from your rootlogon.C macro.
+  images into a directory structure that mirrors that of the ROOT file.  Most
+  style options can be controlled from your rootlogon.C macro.
 
 Power users: advanced operation using configuration files is described in the
   full online documentation.  This allows you control over colors, styles,
-  names for the legends, and more.  Get the default config with --config.
+  names for the legends, and more.  Get the default config with --config, make
+  your changes, and include it as an argument on the command line.
 
 Matplotlib: if you have the matplotlib python plotting library installed on your
   system, you can produce output in matplotlib.  This will be activated by
@@ -1095,6 +1131,10 @@ Matplotlib: if you have the matplotlib python plotting library installed on your
                       help="only process plot(s) in the given location or its "
                       "subdirectories; PATH may be a regular expression (use "
                       ".* for wildcard)")
+    parser.add_option('--ymax', type='float', default=None,
+                      help="set the maximum value of the y-axis")
+    parser.add_option('--ymin', type='float', default=None,
+                      help="set the minimum value of the y-axis")
     parser.add_option('--normalize', metavar='VALUE', default=None,
                       help="if integer, normalize to the VALUEth file "
                       "(starting with 1); if float, scale by VALUE")
